package internal

import (
	"context"
	"encoding/json"
	"fmt"
	"gitea.cdlsxd.cn/BaseSystem/plugin/proto"
	"github.com/stretchr/testify/assert"
	"plugins/utils/weixin"
	"testing"
)

var server = &WeiXinCpnService{}

func config() []byte {
	c := &weixin.Server{
		MchID:                      "1605446142",
		MchCertificateSerialNumber: "4D081089DEB385316CBDCB55C070287E4920AC76",
		MchAPIv3Key:                "ChengDuLanSeXiongDi1234567890123",
		PrivateKey:                 "-----BEGIN PRIVATE KEY-----\nMIIEvAIBADANBgkqhkiG9w0BAQEFAASCBKYwggSiAgEAAoIBAQCyDvodpawS3XDZ\nyGRyhrbQhonxBBLmXgMT5A4zwli2FXFlmHnmeexCjILFMwF2OeRWKhVMbe+6fD0U\n3mXA3bBppqQ65fpra6xjmR7iKUB814RIxbG0SoWhWQJCU/hvGL8m56LQclJo9lyX\nvfxKhi7u4iSbC7E0MiEIFSUCdmNZHX2QmMF1pVXBHOBGpR52PE/i+DijwXuvPczD\nm2DLHCFLdFwUnuEnJbOVY7mc3W01zXeAj89IYp6BZxwCgVM+SFxgaK34lB11lDfW\nzAQgNQbfFdZEKYJgJiTlOpXMYNDaTx6GqkUKXrpRXKoDSSuVeGiCCgh0/RATB6sL\nlYO6+/4VAgMBAAECggEANwUvvleCO3YXuAQXHdiIxxi7qTEEEhE8zDmtNcs5FFK9\n7pHWISTNn6bBheQD8J9k8kcgu7RA3pQjX751HMqkB5GJr/V+kxD7fO9EvsfWeH00\nEDSee8KHVlsluo8t9k5kSsZK5jRdSLfP1sfLHNAn0oMoooxTXnibAl9eR0uD2XYh\n2LTCdbg1Y6UkObf6ikPJI6D6P9F9madzW2zraCXgr42SWYFGEv0iAGXxG9uXc3KU\n81XJa8IIEB4Tlsijx3Zk5ASN/z9K7rJIwciTnHfKJiicTMzjF3CvvhsmrpRVbX4j\nZRPyXgMdGOdCn8u9ZgDnl9A0mnqSQEzLWaAsrbI9hQKBgQDq8B9rhIrEP8J+iD16\nUPpVE224SWlU/2CM1chs/uE6jh3s5XoK+wGoXKjAIEOG9jl2BuUYg0yPsybE8QFc\npAYpz24GGdCxIuQZIL37UoV3CKMeREo7KXG++nmCMQZ3GPPvlXSx3ugDTH76GbRq\nx5uLwbX0L2ewD88IQOvbkpVpdwKBgQDCBXVDWlwgA1mZhOjOp8NO68fDTdhnrKCf\nJS1QmNofCepqSn3s76l19V2F9b888TbIjWQDkmN9BhLisZ/9RqJEb5zrgP+x4DfB\nhKxpsugF4h5/C4ZvpjRGlOu38qQp0k0TuQBjGGHBEZQiE2TgvUx6V4jAHBRpUXh6\nqaZHHJ630wKBgF3h+NxRSdakmAdSUCbp5y9KJUVIaMQjjSSaZY5QyBZLJmA9T2jF\n52KtLG4iNnnfORUWKkSCa3zdHXgDywSHM0NP9eqQNFok1DvKXsDouBbaJ7z3kyZT\nKHYlx5qkFq5PFWO/OLO/nL18ux0cWoF1JI5TqW9b5jZwCs6Eivvidrx/AoGABVTz\nEQPFrleJOc/OOgegNWYDWlmkTc0PqO/zm9hnfhzepUcgyMcZSBWTGWBUfg8+6yn/\nip2WQFRPZo1tER/Ey86paEtmO3Qm9Bl6R3lUKP06y1D8w8q0exASnj57xm5yEc2u\ntgpwfUbHZFxWFFr/ZAlNx8G9ydskTXKmECQ4NGMCgYBvZe4M86EW2j0VBH7f/eUj\nPiCoRGjcM6CMlDArCtcw0d62URr9li8hTtB0aGW0qC1Q/ge+adkw6rhw7WQO7Dag\nOxjaGYcpryIDuiliDG6U0yB8rqA9aW7k3npvivmeX/1mAtGGrliAAX4bb/y3S0nJ\nDwIaCyy1x9BH0libPZpSYA==\n-----END PRIVATE KEY-----\n",
		PrivateKeyPath:             "/Users/lsxd/code/go/other/mq/wx/wechat_private_key.pem",
	}
	marshal, _ := json.Marshal(c)
	return marshal
}

func TestOrder(t *testing.T) {
	request := &proto.OrderRequest{
		Config: config(),
		Order: &proto.OrderRequest_Order{
			OrderNo: "240403164049635931",
			Account: "oO3vO5AxRWgTjmMD38FTvnB5Rq6o",
			Extra:   []byte(`{"app_id":"13100720242", "stock_creator_mchid":"stock_creator_mchid"}`),
		},
		Product: &proto.OrderRequest_Product{
			ProductNo: "3102024032977191",
			Extra:     []byte(`{}`),
		},
	}
	t.Run("TestOrder", func(t *testing.T) {
		got, err := server.Order(context.Background(), request)
		if err != nil {
			t.Errorf("Order() error = %v", err)
			return
		}
		fmt.Printf("%+v", got)
		assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}

func TestQuery(t *testing.T) {
	request := &proto.QueryRequest{
		Config: config(),
		Order: &proto.QueryRequest_Order{
			OrderNo: "",
			TradeNo: "69445765514",
			Account: "oO3vO5AxRWgTjmMD38FTvnB5Rq6o",
			Extra:   []byte(`{"app_id":"wx9ed74283ad25bca1"}`),
		},
	}
	t.Run("TestQuery", func(t *testing.T) {
		got, err := server.Query(context.Background(), request)
		if err != nil {
			t.Errorf("Query() error = %v", err)
			return
		}
		fmt.Printf("%+v \n", got)
		assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}

func TestNotify(t *testing.T) {
	in := &proto.NotifyRequest{
		Config:  config(),
		Queries: []byte(``),
		Headers: []byte(``),
		Body: []byte(`{
  "id": "240fd59e-13a3-5e8b-84a8-6608d535f606",
  "create_time": "2024-08-19T17:29:15+08:00",
  "resource_type": "encrypt-resource",
  "event_type": "COUPON.USE",
  "summary": "代金券核销通知",
  "original_type": "coupon",
  "associated_data": "coupon",
  "plain_text": {
    "stock_creator_mchid": "1652465541",
    "stock_id": "19345605",
    "coupon_id": "71916331907",
    "coupon_name": "三湘银行200元立减",
    "description": "",
    "status": "USED",
    "create_time": "2024-08-19T17:28:11+08:00",
    "coupon_type": "NORMAL",
    "no_cash": false,
    "singleitem": false,
    "consume_information": {
      "consume_time": "2024-08-19T17:29:15+08:00",
      "consume_mchid": "1319713401",
      "transaction_id": "4200002399202408192628783906"
    }
  }
}
`),
	}
	t.Run("TestNotify", func(t *testing.T) {
		got, err := server.Notify(context.Background(), in)
		if err != nil {
			t.Errorf("Notify() error = %v", err)
			return
		}
		fmt.Printf("TestNotify : %+v \n", got)
		assert.Equal(t, int(proto.Status_SUCCESS), int(got.Result.Status))
	})
}
